#Analysis of the fluctuation experiment

#Load Neurospora functions
source("Neuro_functions.R")

### * Analysis of the fluctuation data...

aineisto <- read.csv("fluct_data.csv", header = T)


#Here is the data for longer frequencies
aineisto.long <- read.csv("fluct_data_long.csv", header = T)


### ** Calculate growth rates and check data quality

#Check that there are no obvious errors in the data
qc.neuro(aineisto, 7:18)

gr <- calc.lin.gr(aineisto, 7:18, 4, tindex)
aineisto <- cbind(aineisto, gr)

#For longer frequencies
qc.neuro(aineisto.long, 7:14)

gr.long <- calc.lin.gr(aineisto.long, 7:16, 4, tindex)
aineisto.long <- cbind(aineisto.long, gr.long)

#Looking at R2 values
#quantile(gr[,2], probs = c(0.025, 0.5, 0.975), na.rm = TRUE)

#Note that there are no "bad" cases in aineisto.long

#Look at cases where R2 are "bad"
#aineisto[order(gr[,2], decreasing = TRUE),c(1:6,19,20,21)]

#Check problematic ones by eye
#plot.gr(aineisto, 112, 7:18, 4, tindex)
#plot.gr(aineisto, 359, 7:18, 4, tindex)
#plot.gr(aineisto, 293, 7:18, 4, tindex) #Even the worse ones are quite good

#koe <- plot(growthrate ~ factor(GCham), data = aineisto) #Quite large growth chamber effects
#koe <- plot(growthrate ~ factor(Freq), data = aineisto)

#koe <- plot(growthrate ~ factor(GCham), data = aineisto.long) #Growth chamber effects are large, chamber 5 is the OK one

#Adjusting for growth chamber effects

malli <- lm(growthrate ~ factor(GCham) + factor(Freq) + factor(block), data = aineisto) #There is a  growth chamber effect. Block effect is not significant

#summary(aov(malli)) #Growth chamber, frequency significant, block marginal

#Remove growth chamber effect
#malli2 <- lm(growthrate ~ Genotype + factor(GCham) + factor(Freq), data = aineisto)
chamber.effects <- coef(malli)
gr.chamber <- aineisto$growthrate - (chamber.effects[2] * (aineisto$GCham == 2)) - (chamber.effects[3] * (aineisto$GCham == 3)) - (chamber.effects[4] * (aineisto$GCham == 4)) - (chamber.effects[5] * (aineisto$GCham == 5)) - (chamber.effects[6] * (aineisto$GCham == 6))

aineisto <- cbind(aineisto, gr.chamber)


#Since short frequencies are adjusted to chamber 1, so long frequencies have to be also adjusted to chamber 2 which has the corresponding temperature in this experiment
#plot(growthrate ~ factor(GCham), data = aineisto.long) #Plot of growth chamber effects.

aineisto.long$GCham <- factor(aineisto.long$GCham)
aineisto.long$GCham <- relevel(aineisto.long$GCham, "2")
malli.long <- lm(growthrate ~ factor(GCham) + factor(Freq) + factor(block), data = aineisto.long)
#Removing growth chamber effects from long frequency data
chamber.effects.long <- coef(malli.long)
gr.long.adj <- aineisto.long$growthrate - (chamber.effects.long[2] * (aineisto.long$GCham == "1")) - (chamber.effects.long[3] * (aineisto.long$GCham == "5"))

#plot(gr.long.adj ~ aineisto.long$GCham)
aineisto.long <- cbind(aineisto.long, gr.long.adj)



### ** Modeling growth in fluctuating temperature
### *** Loading data from constant temperatures
#First I need to load the data for constant environments
#Use the data from previous experiment

#Load the data from previous experiment
#Loading some data from a previous experiment, See Kronholm et al. 2016. Epigenetic Control of Phenotypic Plasticity in the Filamentous Fungus Neurospora crassa. G3 6: 4009-4022

data.con <- read.csv("tempdata.csv", header = TRUE, na.strings = "NA")
gr <- calc.lin.gr(data.con, 7:18, 4, tindex)
data.con <- cbind(data.con, gr)
data.con[729,19:20] <- c(NA, NA) #One outlier observation removed (check previous analysis)

temp.means <- summarySE(data = data.con, measurevar = "growthrate", groupvars = c("Level", "Genotype"), na.rm = TRUE)

valid.data2 <- read.csv("validt40_2.csv", header = TRUE, na.strings = "NA")
gr <- calc.lin.gr(valid.data2, 7:18, 4, tindex)
valid.data2 <- cbind(valid.data2, gr)

#Need to take care of block effects in the previous data, same as in the previous experiment

koe <- valid.data2[(valid.data2$GCham == 1),]
#Removing block effects
#malli2 <- lm(growthrate ~ Genotype + shelf + factor(block), data = koe)
block.effects <- coef(lm(growthrate ~ shelf + factor(block), data = koe))
gr.block <- koe$growthrate  - (block.effects[2] * (koe$shelf == "top")) - (block.effects[3] * (koe$block == 2)) - (block.effects[4] * (koe$block == 3))
koe <- cbind(koe, gr.block)

valid.temp <- read.csv("validt3035.csv", header = TRUE, na.strings = "NA")
gr <- calc.lin.gr(valid.temp, 7:18, 4, tindex)
valid.temp <- cbind(valid.temp, gr)

valid.temp30 <- valid.temp[(valid.temp[,2] == 30),]
valid.temp35 <- valid.temp[(valid.temp[,2] == 35),]

valid.temp30[,3] <- factor(valid.temp30[,3])
valid.temp35[,3] <- factor(valid.temp35[,3]) #Re-level the factors

#+30 C Stats
malli <- lm(growthrate ~ Genotype + factor(GCham) + shelf + factor(block), data = valid.temp30)
#Block effects
bc <- valid.temp30[,21] - (valid.temp30$shelf == "top") * coef(malli)[6]
bc <- bc - (valid.temp30$block == 2) * coef(malli)[7]
bc <- bc - (valid.temp30$block == 3) * coef(malli)[8]
bc <- bc - (valid.temp30$GCham == 2) * coef(malli)[5]
bc30 <- bc
valid.temp30 <- cbind(valid.temp30, bc30)

#+35 Stats
malli <- lm(growthrate ~ Genotype + factor(GCham) + shelf + factor(block), data = valid.temp35)
#Block effects
bc <- valid.temp35[,21] - (valid.temp35$shelf == "top") * coef(malli)[6]
bc <- bc - (valid.temp35$block == 2) * coef(malli)[7]
bc <- bc - (valid.temp35$block == 3) * coef(malli)[8]
bc <- bc - (valid.temp35$GCham == 2) * coef(malli)[5]
bc35 <- bc
valid.temp35 <- cbind(valid.temp35, bc35)

#Growth rate of 2489 at 30, 35, and 40 degress is
temp40.2489 <- summarySE(data = koe, measurevar = "gr.block", groupvars = "Genotype", na.rm = TRUE)[2,]

temp35.2489 <- summarySE(data = valid.temp35, measurevar = "bc35", groupvars = "Genotype", na.rm = TRUE)[2,]

temp30.2489 <- summarySE(data = valid.temp30, measurevar = "bc30", groupvars = "Genotype", na.rm = TRUE)[2,]

#Dataframe for constant environment growth
const.control <- data.frame(matrix(rep(0,3*4), ncol = 4))
colnames(const.control) <- c("Genotype", "Temperature", "growthrate", "se")
const.control[,1] <- rep("cont2489", 3)
const.control[,2] <- c(30, 35, 40)
const.control[,3] <- unlist(c(temp30.2489[3], temp35.2489[3], temp40.2489[3]))
const.control[,4] <- unlist(c(temp30.2489[5], temp35.2489[5], temp40.2489[5]))

#Making a combined dataset with growth in constant and fluctuating temps
#constant temp.data in temp.means
#temp.meanslevels(aineisto$Genotype)
conind <- temp.means$Genotype %in% levels(aineisto$Genotype)
temp.means <- temp.means[conind,]
cont.temps <- temp.means[temp.means$Level == 30 | temp.means$Level == 40,]
rownames(cont.temps) <- 1:38 #Need to reset rownames because it was annoying...
#Temps at 30 are okay, but for 40 there needs to be a correction, for experiment effects
t40 <- summarySE(data = koe, measurevar = "gr.block", groupvars = "Genotype", na.rm = TRUE)
cont.temps[20,4] <- t40[1,3] #aof2 gr
cont.temps[23,4] <- t40[3,3] #dim-2
cont.temps[35,4] <- t40[5,3] #qip
cont.temps[38,4] <- t40[6,3] #set-7
#Correction factor (control old - control new)
cf <- 3.3666109 - 2.415105
cont.temps[21,4] <- cont.temps[21,4] - cf #dcl-1
cont.temps[22,4] <- cont.temps[22,4] - cf #dcl-2
cont.temps[24,4] <- cont.temps[24,4] - cf #dmm-2
cont.temps[25,4] <- t40[1,3] #elp3 to same constant as aof2
cont.temps[27,4] <- 2.415105 #hda-4 to same constant as control
cont.temps[28,4] <- t40[1,3] #lid2 to same constant as aof2
cont.temps[29,4] <- t40[2,3] #nst-1 to same constant as control
cont.temps[30,4] <- t40[2,3] #nst-2 to same constant as control
cont.temps[31,4] <- t40[2,3] #nst-4 to same constant as control
cont.temps[33,4] <- cont.temps[33,4] - cf #qde-1
#Making the final vector for easier handling
cont.temps40 <- cont.temps[cont.temps$Level == 40,c(2,4)]

#Adding constant temps to the whole dataset
#Note need to add control separately
c40 <- rep(0, nrow(aineisto))
for(i in 1:nrow(aineisto)) {
    m.ind <- match(aineisto$Genotype[i], cont.temps40[,1])
    c40[i] <- cont.temps40[m.ind,2]
}
c40[is.na(c40)] <- 2.415105 #Set control and Dicer double mutant to growth of control

#Constant growth at +30
cont.temps30 <- cont.temps[cont.temps$Level == 30, c(2,4)]
c30 <- rep(0, nrow(aineisto))
for(i in 1:nrow(aineisto)) {
    m.ind <- match(aineisto$Genotype[i], cont.temps30[,1])
    c30[i] <- cont.temps30[m.ind,2]
}
c30[is.na(c30)] <- unlist(temp30.2489[3])

#Final dataframe with also constant temperatures included
aineisto <- cbind(aineisto,c40,c30)

#Data for plot of reaction norm of 4200 across all temperatures
cont4200 <- temp.means[temp.means$Genotype == "cont4200",]

### *** Calculating different growth models


all.geno <- summarySE(data = aineisto, measurevar = "gr.chamber", groupvars = c("Freq", "Genotype"), na.rm = TRUE)
colnames(all.geno)[4] <- "growthrate"
control <- all.geno[all.geno$Genotype == "cont2489",]

#Model with growth based on constant reaction norms

#The model has to be something like:
#growth = time in 30C * growthrate at 30C + time in 40C * growthrate at 40C
temp30.2489
temp40.2489

#Naive model with no lag
#Frequency 30 min
0.5*temp30.2489[3] + 0.5*temp40.2489[3] #3.384509 mm -> total time 1 h is 3.3845 mm / h
#Real growth at 30 min freq is 2.508 mm / h
#Freq of 60 min
1*temp30.2489[3] + 1*temp40.2489[3] #6.769 mm -> total time 2h is the same 3.3845 mm / h

#If there is no lag, plasticity is instantaneous, frequency of fluctuation should have no effect
#on growth rate measured over the whole growth assay.

#
### ** Plotting control in fluctuating and constant environments

library(grid)
library(gridBase)
library(cowplot)

#Figure of reaction norm in constant environments
limits <- aes(ymax = growthrate + se, ymin=growthrate - se)

my.xlab <- expression(paste("Temperature (", degree,"C)"))
cont.constant.rnorm <- ggplot(const.control, aes(x = Temperature, y = growthrate)) +
    geom_point() +
    geom_line(size = 1) +
    geom_errorbar(limits, width = 0.05) +
    ylim(2, 5.5) +
    labs(y = "Growth rate (mm / h)", x = my.xlab) +
    background_grid(major = "xy", minor = "none")

#Using the growth rate measure where growth chamber effects have been subtracted
all.geno <- summarySE(data = aineisto, measurevar = "gr.chamber", groupvars = c("Freq", "Genotype"), na.rm = TRUE)
colnames(all.geno)[4] <- "growthrate"

#all.geno <- summarySE(data = aineisto, measurevar = "growthrate", groupvars = c("Freq", "Genotype"), na.rm = TRUE)

limits <- aes(ymax = growthrate + se, ymin=growthrate - se)

#ggplot(all.geno, aes(x = Freq, y = growthrate, group = Genotype, colour = Genotype)) +
#    geom_point() +
#    geom_line(size = 1) +
#    geom_errorbar(limits, width = 0.05) +
#    labs(y = "Growth rate (mm / h)", x = "Frequency (min)")
     

#For long frequencies
all.geno.long <- summarySE(data = aineisto.long, measurevar = "gr.long.adj", groupvars = c("Freq", "Genotype"), na.rm = TRUE)
colnames(all.geno.long)[4] <- "growthrate"

#ggplot(all.geno.long, aes(x = Freq, y = growthrate, group = Genotype, colour = Genotype)) +
#    geom_point() + 
#    geom_line(size = 1) +
#    geom_errorbar(limits, width = 0.05) +
#    labs(y = "Growth rate (mm / h)", x = "Frequency (min)")

#Combine short and long time durations
all.geno.temp <- all.geno
all.geno.temp$Freq <- (as.numeric(as.character(all.geno.temp$Freq)))
all.geno.complete <- rbind(all.geno.temp, all.geno.long)



#Need to run some stuff from later before this works
control.only <- all.geno.complete[all.geno.complete$Genotype == "cont2489",]
#pdf("cont_fluctnorm.pdf", width = 10)
cont.fluc.rnorm <- ggplot(control.only, aes(x = Freq, y = growthrate)) +
    geom_line(size = 1) +
    geom_point(size = 2, fill = "white") +
    geom_errorbar(limits, width = 0.05) +
    geom_hline(aes(yintercept = temp40.2489[3]), colour = "red") +
    geom_hline(aes(yintercept = temp40.2489[3]-temp40.2489[5]), linetype = 2, colour = "red") +
    geom_hline(aes(yintercept = temp40.2489[3]+temp40.2489[5]), linetype = 2, colour = "red") +
    geom_hline(aes(yintercept = temp30.2489[3]), colour = "blue") +
    geom_hline(aes(yintercept = temp30.2489[3]-temp30.2489[5]), linetype = 2, colour = "blue") +
    geom_hline(aes(yintercept = temp30.2489[3]+temp30.2489[5]), linetype = 2, colour = "blue") +    
    labs(y = "Growth rate (mm / h)", x = "Step duration (min)") +
    scale_x_continuous(breaks = c(30, 60, 90, 120, 150, 240, 480, 720)) +
    ylim(2, 4.5) +
    background_grid(major = "xy", minor = "none")      
#dev.off()

cont.rnorms <- plot_grid(cont.constant.rnorm, cont.fluc.rnorm, rel_widths = c(1,2), labels = c("A", "B"))
save_plot("rnorms2.pdf", cont.rnorms, base_width = 12)

### ** Plotting the individual genotypes

### *** Selected mutants for plotting (for presentation)

allstars.geno <- all.geno.complete[all.geno.complete$Genotype == "cont2489" | all.geno.complete$Genotype == "dim-2" | all.geno.complete$Genotype == "hda-1" | all.geno.complete$Genotype == "qde-2" | all.geno.complete$Genotype == "set-1" | all.geno.complete$Genotype == "set-2" | all.geno.complete$Genotype == "set-7",]

pdf("allstars.pdf", width = 10, height = 7)
ggplot(allstars.geno, aes(x = Freq, y = growthrate, group = Genotype, colour = Genotype, shape = Genotype)) +
    geom_line(size = 1) +
    geom_point(size = 2, fill = "white") +
    scale_shape_manual(values=c(21,22,23,24,25,7,4), labels = c("Control", "dim-2 (DNA methylation)", "hda-1 (Histone deacetylation)", "qde-2 (milRNA)", "set-1 (H3K4me3)", "set-2 (H3K36me)", "set-7 (H3K27me3)") ) +
    geom_errorbar(limits, width = 0.05) +
    labs(y = "Growth rate (mm / h)", x = "Step duration (min)") +
    ylim(1, 3.5) +
    scale_x_continuous(breaks = c(30, 60, 90, 120, 150, 240, 480, 720)) +    
    scale_colour_manual(values = cbbPalette, labels = c("Control", "dim-2 (DNA methylation)", "hda-1 (Histone deacetylation)", "qde-2 (milRNA)", "set-1 (H3K4me3)", "set-2 (H3K36me)", "set-7 (H3K27me3)")) +
     theme(legend.position = c(.5, .25), legend.background = element_rect(fill="transparent")) +
    background_grid(major = "xy", minor = "none")
dev.off()

### *** DNA methylation mutants

meth.geno <- all.geno.complete[all.geno.complete$Genotype == "cont2489" | all.geno.complete$Genotype == "dim-2" | all.geno.complete$Genotype == "dmm-2",]

plot.meth <- ggplot(meth.geno, aes(x = Freq, y = growthrate, group = Genotype, colour = Genotype)) +
    geom_point() +
    geom_line(size = 1) +
    geom_errorbar(limits, width = 0.05) +
    labs(y = "Growth rate (mm / h)", x = "Step duration (min)") +
    ylim(1, 3.5) +
    scale_x_continuous(breaks = c(30, 60, 90, 120, 150, 240, 480, 720)) +
    scale_colour_manual(values = cbbPalette, labels = c("Control", "dim-2 (DNA methylation)", "dmm-2")) +
    theme(legend.position = c(.5, .25), legend.background = element_rect(fill="transparent")) +
    background_grid(major = "xy", minor = "none")

### *** Histone methylation mutants

hist.geno <- all.geno.complete[all.geno.complete$Genotype == "cont2489" | all.geno.complete$Genotype == "set-1" | all.geno.complete$Genotype == "set-2" | all.geno.complete$Genotype == "set-7",]

plot.hist <- ggplot(hist.geno, aes(x = Freq, y = growthrate, group = Genotype, colour = Genotype)) +
    geom_point() +
    geom_line(size = 1) +
    geom_errorbar(limits, width = 0.05) +
    labs(y = "Growth rate (mm / h)", x = "Step duration (min)") +
    ylim(1, 3.5) +
    scale_x_continuous(breaks = c(30, 60, 90, 120, 150, 240, 480, 720)) +
    scale_colour_manual(values = cbbPalette, labels = c("Control", "set-1 (H3K4me3)", "set-2 (H3K36me)", "set-7 (H3K27me3)")) +
    theme(legend.position = c(.5, .25), legend.background = element_rect(fill="transparent")) +
    background_grid(major = "xy", minor = "none")    

### *** Histone deacetylation mutants

histdeacet.geno <- all.geno.complete[all.geno.complete$Genotype == "cont2489" | all.geno.complete$Genotype == "hda-1" | all.geno.complete$Genotype == "hda-4",]

plot.deacet1 <- ggplot(histdeacet.geno, aes(x = Freq, y = growthrate, group = Genotype, colour = Genotype)) +
    geom_point() +
    geom_line(size = 1) +
    geom_errorbar(limits, width = 0.05) +
    labs(y = "Growth rate (mm / h)", x = "Step duration (min)") +
    ylim(1, 3.5) +
    scale_x_continuous(breaks = c(30, 60, 90, 120, 150, 240, 480, 720)) +  
    scale_colour_manual(values = cbbPalette, labels = c("Control", "hda-1", "hda-4")) +
    theme(legend.position = c(.5, .25), legend.background = element_rect(fill="transparent")) +
    background_grid(major = "xy", minor = "none")    

### *** Histone deacetylation mutants, class III

deacetIII.geno <- all.geno.complete[all.geno.complete$Genotype == "cont2489" | all.geno.complete$Genotype == "nst-1" | all.geno.complete$Genotype == "nst-2" | all.geno.complete$Genotype == "nst-4" | all.geno.complete$Genotype == "nst-7",]

plot.deacet3 <- ggplot(deacetIII.geno, aes(x = Freq, y = growthrate, group = Genotype, colour = Genotype)) +
    geom_point() +
    geom_line(size = 1) +
    geom_errorbar(limits, width = 0.05) +
    labs(y = "Growth rate (mm / h)", x = "Step duration (min)") +
    ylim(1, 3.5) +
    scale_x_continuous(breaks = c(30, 60, 90, 120, 150, 240, 480, 720)) +  
    scale_colour_manual(values = cbbPalette, labels = c("Control", "nst-1", "nst-2", "nst-4", "nst-7")) +
    theme(legend.position = c(.5, .25), legend.background = element_rect(fill="transparent")) +
    background_grid(major = "xy", minor = "none")        

### *** RNA interference mutants

rna.geno <- all.geno.complete[all.geno.complete$Genotype == "cont2489" | all.geno.complete$Genotype == "dcl-1" | all.geno.complete$Genotype == "dcl-2" | all.geno.complete$Genotype == "dcl-1 dcl-2" | all.geno.complete$Genotype == "qde-1" | all.geno.complete$Genotype == "qde-2" | all.geno.complete$Genotype == "qip",]

plot.rna <- ggplot(rna.geno, aes(x = Freq, y = growthrate, group = Genotype, colour = Genotype)) +
    geom_point() +
    geom_line(size = 1) +
    geom_errorbar(limits, width = 0.05) +
    labs(y = "Growth rate (mm / h)", x = "Step duration(min)") +
    ylim(1, 3.5) +
    scale_x_continuous(breaks = c(30, 60, 90, 120, 150, 240, 480, 720)) +     
    scale_colour_manual(values = cbbPalette, labels = c("Control", "dcl-1 (Dicer)", "dcl-2 (Dicer)", "dcl-1 dcl-2 (Dicer)", "qde-1 (RNA pol)", "qde-2 (Argonaute)", "qip (Exonuclease)")) +
    theme(legend.position = c(.5, .25), legend.background = element_rect(fill="transparent")) +
    background_grid(major = "xy", minor = "none")       

### *** Other mutants

other.geno <- all.geno.complete[all.geno.complete$Genotype == "cont2489" | all.geno.complete$Genotype == "aof2" | all.geno.complete$Genotype == "elp3" | all.geno.complete$Genotype == "lid2",]

cbbPalette2 <- c(cbbPalette[2],cbbPalette[1],cbbPalette[3:8])
plot.other <- ggplot(other.geno, aes(x = Freq, y = growthrate, group = Genotype, colour = Genotype)) +
    geom_point() +
    geom_line(size = 1) +
    geom_errorbar(limits, width = 0.05) +
    labs(y = "Growth rate (mm / h)", x = "Step duration (min)") +
    ylim(1, 3.5) +
    scale_x_continuous(breaks = c(30, 60, 90, 120, 150, 240, 480, 720)) +      
    #scale_colour_manual(values = cbbPalette, labels = c("aof2", "Control", "elp3", "lid2"))
    scale_colour_manual(values = cbbPalette2, breaks = c("cont2489", "aof2", "elp3", "lid2"), labels = c("Control", "aof2", "elp3", "lid2")) +
    theme(legend.position = c(.5, .25), legend.background = element_rect(fill="transparent")) +
    background_grid(major = "xy", minor = "none")    

### *** Building one plot

#It is a bit difficult to fit everything into one plot that looks OK in the PDF. May need do trials.
mutant.panel.plot <- plot_grid(plot.meth, plot.hist, plot.deacet1, plot.deacet3, plot.rna, plot.other, labels = c("A", "B", "C", "D", "E", "F"), ncol = 2)
save_plot("mutant_rnorms.pdf", mutant.panel.plot, ncol = 2, nrow = 3, base_height = 5, base_width = 8 )

### ** Statistical analysis of the data

#Need to use the same sort of mixed modeling approach as in the previous experiment

#Fitting mixed models using lmer package
#aineisto$gr.chamber contains the chamber and block effect corrected growth rates
#Setting the frequencies as factors
library(lmerTest)

aineisto$Freq <- factor(aineisto$Freq)

model <- lmer(gr.chamber ~ Freq + (1 | Genotype) +  (1 | Freq:Genotype), data = aineisto )
anova(model) #gives table for fixed effects
rand(model) #gives table for random effects
#tulos.model <- Anova(model, type = "3", adjustSigma = F, singular.ok = TRUE, test.statistic = "F")

#Conclusion is that epigenetic effects do not have any particular effect in fluctuating environments

aineisto2 <- aineisto

model2 <- lmer(gr.chamber ~ Freq + (1 | Genotype) + (1 | Freq:Genotype), data = aineisto2)
anova(model2) #Fixed effects 
rand(model2) #random effects
randmodel2 <- data.frame(rand(model2)[1]) #Store random effect table as data frame

#Analysis of short and long step durations together
#Need to take columns, 2, 3, and 22 from both

#First need to adjust some names etc. 
ain.temp <- aineisto2[,c(2,3,22)]
ain.temp$Freq <- as.numeric(as.character(ain.temp$Freq)) #Change temporarely to numbers
colnames(ain.temp)[3] <- "gr.adj"
ain.temp.long <- aineisto.long[,c(2,3,22)]
colnames(ain.temp.long)[3] <- "gr.adj"

aineisto3 <- rbind(ain.temp, ain.temp.long)
aineisto3$Freq <- factor(aineisto3$Freq)

#Analysis of combined data
model3 <- lmer(gr.adj ~ Freq + (1 | Genotype) + (1 | Freq:Genotype), data = aineisto3)
anova(model3) #Effect of time is significant
rand(model3) #Both effect of genotype and interaction are significant
randmodel3 <- data.frame(rand(model3)[1])

#Testing each mutant at a time, by performing a pairwise ANOVA

mutants <- levels(aineisto3$Genotype)[-2] #List of all mutants, control dropped

pairw.res <- pairwise.ANOVA.GxE(aineisto3, mutants, control.name = "cont2489", genotype.col.no = 2, environ.col.no = 1, phenotype.col.no = 3)


### * Analysis of the lag time experiments

### ** Lag experiment

lagdata4 <- read.csv("lag_data.csv", header = T)
tindex.45 <- c(0, 8, 24, 25, 26, 27, 28, 29, 30, 31, 32, 49, 56)
tempdex.7 <- c(rep(30,3), rep(40, 10))
tempdex.8 <- c(rep(40,3), rep(30, 10))

qc.neuro(lagdata4, 3:15) #OK

#Separate data by switch, from 40 to 30 degrees and 30 to 40 degrees
lagdata.40to30 <- lagdata4[lagdata4[,17] == 8,]
lagdata.30to40 <- lagdata4[lagdata4[,17] == 7,]

#For switch from 40 to 30 ###
#Making a results matrix
#time <- c(rep(0, 20), rep(2, 20), rep(5, 20), rep(7, 20), rep(9, 20), rep(11,20), rep(23,20), rep(30,20))
res.mat.40to30 <- data.frame(matrix(rep(0,7*20*4), ncol = 4)) #Dimensions 140,7
colnames(res.mat.40to30) <- c("genotype", "block", "time", "growthrate")
res.mat.40to30[,1] <- rep(lagdata.40to30[,1], 7)
res.mat.40to30[,2] <- rep(lagdata.40to30[,16], 7)
res.mat.40to30[,3] <- c(rep(0, 20), rep(2, 20), rep(4, 20), rep(6, 20), rep(8, 20), rep(25,20), rep(32,20))

distances <- lagdata.40to30[,-c(1,2,16,17)]

#Gr at +40
res.mat.40to30[1:20,4] <- (distances[3] - distances[1]) / (tindex.45[3] - tindex.45[1]) #Initial at 40
#Time points at 30
res.mat.40to30[21:40,4] <- (distances[5] - distances[3]) / (tindex.45[5] - tindex.45[3]) #2 hours
res.mat.40to30[41:60,4] <- (distances[7] - distances[5]) / (tindex.45[7] - tindex.45[5]) #4 hours
res.mat.40to30[61:80,4] <- (distances[9] - distances[7]) / (tindex.45[9] - tindex.45[7]) #6 hours
res.mat.40to30[81:100,4] <- (distances[11] - distances[9]) / (tindex.45[11] - tindex.45[9]) #8 hours
res.mat.40to30[101:120,4] <- (distances[12] - distances[11]) / (tindex.45[12] - tindex.45[11]) # 25 h
res.mat.40to30[121:140,4] <- (distances[13] - distances[12]) / (tindex.45[13] - tindex.45[12]) # 32 h

summary.40to30 <- summarySE(data = res.mat.40to30, measurevar = "growthrate", groupvars = c("genotype", "time"), na.rm = TRUE)

plot.40to30 <- ggplot(summary.40to30, aes(x = time, y = growthrate, group = genotype, colour = genotype)) +
    geom_point() +
    geom_line(size = 1) +
    geom_errorbar(limits, width = 0.05) +
    expand_limits(x = -1) +
    geom_vline(aes(xintercept = 0), linetype = "dashed") +
    annotate("text", x = c(-1.5,1.5), y = c(4.4,4.4), label = c("40 C", "30 C")) +   
    labs(y = "Growth rate (mm / h)", x = "Time since temperature switch (h)") +
    background_grid(major = "xy", minor = "none") +
    scale_colour_manual(values = c("black", "darkgrey"),  labels = c("2489", "qde-2")) +
    scale_x_continuous(breaks=seq(0, 32, 2)) +
    scale_y_continuous(limits =c(1.5, 4.6), breaks=seq(1.5, 4.5, .5)) +
    theme(legend.position = c(0.8,0.2))    

#For switch from 30 to 40 ###
#Making a results matrix
res.mat.30to40 <- data.frame(matrix(rep(0,7*20*4), ncol = 4)) #Dimensions 140,7
colnames(res.mat.30to40) <- c("genotype", "block", "time", "growthrate")
res.mat.30to40[,1] <- rep(lagdata.30to40[,1], 7)
res.mat.30to40[,2] <- rep(lagdata.30to40[,16], 7)
res.mat.30to40[,3] <- c(rep(0, 20), rep(2, 20), rep(4, 20), rep(6, 20), rep(8, 20), rep(25,20), rep(32,20))

distances <- lagdata.30to40[,-c(1,2,16,17)]

#Gr at +30
res.mat.30to40[1:20,4] <- (distances[3] - distances[1]) / (tindex.45[3] - tindex.45[1]) #Initial at 30
#Time points at 30
res.mat.30to40[21:40,4] <- (distances[5] - distances[3]) / (tindex.45[5] - tindex.45[3]) #2 hours
res.mat.30to40[41:60,4] <- (distances[7] - distances[5]) / (tindex.45[7] - tindex.45[5]) #4 hours
res.mat.30to40[61:80,4] <- (distances[9] - distances[7]) / (tindex.45[9] - tindex.45[7]) #6 hours
res.mat.30to40[81:100,4] <- (distances[11] - distances[9]) / (tindex.45[11] - tindex.45[9]) #8 hours
res.mat.30to40[101:120,4] <- (distances[12] - distances[11]) / (tindex.45[12] - tindex.45[11]) # 25 h
res.mat.30to40[121:140,4] <- (distances[13] - distances[12]) / (tindex.45[13] - tindex.45[12]) # 32 h

summary.30to40 <- summarySE(data = res.mat.30to40, measurevar = "growthrate", groupvars = c("genotype", "time"), na.rm = TRUE)

after1h.30to40 <- (distances[4] - distances[3]) / (tindex.45[4] - tindex.45[3])
mean(after1h.30to40[lagdata.30to40$Genotype == "cont2489",])
after2h.30to40 <- (distances[5] - distances[4]) / (tindex.45[5] - tindex.45[4])
mean(after2h.30to40[lagdata.30to40$Genotype == "cont2489",])

plot.30to40 <- ggplot(summary.30to40, aes(x = time, y = growthrate, group = genotype, colour = genotype)) +
    geom_point() +
    geom_line(size = 1) +
    geom_errorbar(limits, width = 0.05) +
    expand_limits(x = -1) +
    geom_vline(aes(xintercept = 0), linetype = "dashed") +
    annotate("text", x = c(-1.5,1.5), y = c(4.4,4.4), label = c("30 C", "40 C")) +   
    labs(y = "Growth rate (mm / h)", x = "Time since temperature switch (h)") +
    background_grid(major = "xy", minor = "none") +
    scale_colour_manual(values = c("black", "darkgrey"),  labels = c("2489", "qde-2")) +
    scale_x_continuous(breaks=seq(0, 32, 2)) +
    scale_y_continuous(limits =c(1.5, 4.6), breaks=seq(1.5, 4.5, .5)) +
    theme(legend.position = c(0.8,0.8))


#Combined plot
lagtime.panel.plot <- plot_grid(plot.30to40, plot.40to30, labels = c("A", "B"), ncol = 2)
save_plot("lagtime_exp.pdf", lagtime.panel.plot, ncol = 2, nrow = 1, base_height = 6)

### *** Testing differences between the two measured strains
#Analysing the shifts separately.
model2 <- lmer(gr.chamber ~ Freq + (1 | Genotype) + (1 | Freq:Genotype), data = aineisto2)
anova(model2) #Fixed effect of frequency is still significant, even without 15 min data
rand(model2) #random effects
randmodel2 <- data.frame(rand(model2)[1]) #Store random effect table as data frame

#Shift from 30 to 40 (make sure that lmerTest library is loaded)
data30to40 <- res.mat.30to40
data30to40$time <- factor(data30to40$time)
shiftmodel1 <- lmer(growthrate ~ time + (1 | genotype) + (1 | time:genotype), data = data30to40)
anova(shiftmodel1)
rand(shiftmodel1) #Shapes are different
randshiftmodel1 <- data.frame(rand(shiftmodel1)[1])

data40to30 <- res.mat.40to30
data40to30$time <- factor(data40to30$time)
shiftmodel2 <- lmer(growthrate ~ time + (1 | genotype) + (1 | time:genotype), data = data40to30)
anova(shiftmodel2)
rand(shiftmodel2) #Shapes are different
randshiftmodel2 <- data.frame(rand(shiftmodel2)[1])

### *** Fitting functions to the lagtime data
#Need to fit a non-linear function to data to get function to be used in modeling
#Try model on the form of y = b0 - b1*2^{-t/th} + error
#
#2489 only
cont.40to30 <- res.mat.40to30[res.mat.40to30[,1] == "cont2489",]
st.40to30 <- c(b0 = 4.4, b1 = 2, th = 4)
fm.40to30 <- nls(growthrate ~ b0 - b1*2^(-time/th), data = cont.40to30, start = st.40to30, trace = T)

#My own prediction function
my.predict <- function(x) {
    4.453 - 2.028 * 2^(-x/2.064)
}

#Try plotting
plot(c(1,35), c(1.5,4.5), type = "n")
points(cont.40to30[,3], cont.40to30[,4])
lines(seq(0,35,length.out = 100), my.predict(seq(0,35,length.out = 100)))

#Alternative function
#st.a.40to30 <- c(b0 = 4.4, b1 = 2, b3 = 1)
#fm.a.40to30 <- nls(growthrate ~ b0 - b1 * exp(-b3*time), data = cont.40to30, start = st.a.40to30, trace = T)

#my.predict2 <- function(x) {
#    4.4528 - 2.0281 * exp(-0.3359*x)
#}
#Note that these two functions produce the same results (within rounding error)

#
cont.30to40 <- res.mat.30to40[res.mat.30to40[,1] == "cont2489",]
cont.30to40 <- cont.30to40[-c(1:10),]
st.30to40 <- c(b0 = 2.6, b1 = 2, th = 1)
fm.30to40 <- nls(growthrate ~ b0 - b1*2^(-time/th), data = cont.30to40, start = st.30to40, trace = T)

#Note: can get coefficients from nls model with coef(fm.30to40)

my.predict.e2 <- function(x) {
    2.745 - 2.254* 2^(-x/1.376)
}

plot(c(0,35), c(.5,4.5), type = "n")
points(cont.30to40[,3], cont.30to40[,4])
lines(seq(0,35,length.out = 100), my.predict.e2(seq(0,35,length.out = 100)))


### ** Lag experiment with the mutants
### *** Loading the data
library(dplyr)

lagmutants <- read.csv("lag_mutants2.csv", header = T)

qc.neuro(lagmutants, 3:15) #OK

### *** Calculating growth rates for the different time points

#Need to calculate growth rate over two data points, from switch
#Growth rate for constant temp for the three first datapoints

lagmutants30to40 <- filter(lagmutants, tempdex == 7) #subset 30 to 40 data
lagmutants40to30 <- filter(lagmutants, tempdex == 8) #subset 40 to 30 data
const40 <- filter(lagmutants, tempdex == 40)
const30 <- filter(lagmutants, tempdex == 30)

#Calculating growth rates for 2-hour intervals
gr.mutants30to40 <- gr.shift.exp(lagmutants30to40, tindex, col.ind = 2)
lagmutants30to40 <- cbind(lagmutants30to40, gr.mutants30to40)

gr.mutants40to30 <- gr.shift.exp(lagmutants40to30, tindex, col.ind = 2)
lagmutants40to30 <- cbind(lagmutants40to30, gr.mutants40to30)

gr.const40 <- gr.shift.exp(const40, tindex, col.ind = 2)
const40 <- cbind(const40, gr.const40)
const40 <- const40[-1,] #This observation was not in constant 40

gr.const30 <- gr.shift.exp(const30, tindex, col.ind = 2)
const30 <- cbind(const30, gr.const30)
const30 <- const30[-1,] #This observation was not in constant 30

#Making a dataset for calculating lagtimes
lag30to40 <- lagmutants30to40[,-c(3:15,18)]
lag40to30 <- lagmutants40to30[,-c(3:15)]

#Making a summary of the data

const40 <- melt(const40, id.vars = c("Genotype"), measure.vars = c("gr0", "gr2", "gr4", "gr6", "gr8", "gr24.5", "gr32"), variable.name = "time", value.name = "growthrate")
const40 <- group_by(const40, time)
const40.summary <- summarise(const40, gr.n = n(), gr.mean = mean(growthrate), gr.sd = sd(growthrate))

const30 <- melt(const30, id.vars = c("Genotype"), measure.vars = c("gr0", "gr2", "gr4", "gr6", "gr8", "gr24.5", "gr32"), variable.name = "time", value.name = "growthrate")
const30 <- group_by(const30, time)
const30.summary <- summarise(const30, gr.n = n(), gr.mean = mean(growthrate), gr.sd = sd(growthrate))

lagmutants30to40 <- melt(lagmutants30to40, id.vars = c("Genotype", "block"), measure.vars = c("gr0", "gr2", "gr4", "gr6", "gr8", "gr24.5", "gr32"), variable.name = "time", value.name = "growthrate")
lagmutants30to40 <- group_by(lagmutants30to40, Genotype, time)
lagmutants30to40.summary <- summarise(lagmutants30to40, gr.n = my.count(growthrate), gr.mean = mean(growthrate, na.rm = T), gr.sd = sd(growthrate, na.rm = T), gr.se = my.se(gr.n, gr.sd))
lagmutants30to40.summary[,2] <- as.numeric(gsub("gr", "", unlist(lagmutants30to40.summary[,2]))) #Change time to numeric

lagmutants40to30 <- melt(lagmutants40to30, id.vars = c("Genotype", "block"), measure.vars = c("gr0", "gr2", "gr4", "gr6", "gr8", "gr24.5", "gr32"), variable.name = "time", value.name = "growthrate")
lagmutants40to30 <- group_by(lagmutants40to30, Genotype, time)
lagmutants40to30.summary <- summarise(lagmutants40to30, gr.n = my.count(growthrate), gr.mean = mean(growthrate, na.rm = T), gr.sd = sd(growthrate, na.rm = T), gr.se = my.se(gr.n, gr.sd))
lagmutants40to30.summary[,2] <- as.numeric(gsub("gr", "", unlist(lagmutants40to30.summary[,2]))) #Change time to numeric

### *** Calculating the lag times

#Need to use non-linear regression to measure the lag times, so that mutants can be compared to the control
#Fit the same model as previously to data for each replicate and calculate at which point the asymptotic growthrate is reached

#A better to calculate the data
#Fit the nls model to all data points (for a given genotype) simultaneously. Then compare lag times based on standard errors for th

#koe <- filter(lag40to30, Genotype == "cont2489")
#koe <- melt(koe, id.vars = c("Genotype", "block"), measure.vars = c("gr0", "gr2", "gr4", "gr6", "gr8", "gr24.5", "gr32"), variable.name = "time", value.name = "growthrate")
#koe[,3] <- as.numeric(gsub("gr", "", unlist(koe[,3])))

#fit the model
#start.val <- c(b0 = 4.4, b1 = 2, th = 4)
#malli <- nls(growthrate ~ b0 - b1*2^(-time/th), start = start.val, trace = F, data = koe)

#Extract needed coef
#lag50 <- summary(malli)[["coefficients"]][3,1] #time to half growthrate
#lag50.se <- summary(malli)[["coefficients"]][3,2] #SE of time to half growthrate

#There are some issues with different starting values for different genotypes
#Need to do this manually

####  First lag times for 40 to 30 shift  ######
data <- lag40to30

######################Remove the first three replicates (54 lines)
#data <- data[-c(1:54),]
######################

data[,1] <- factor(data[,1]) #Make sure that levels are OK

    genotypes <- levels(data[,1]) #genotypes
    res.mat <- matrix(rep(0, length(genotypes)*3), ncol = 3) #Results matrix, genotype, lag, se
    res.mat <- data.frame(res.mat)

for(i in 1:length(genotypes)) {
        koe <- filter(data, Genotype == genotypes[i])
        koe <- melt(koe, id.vars = c("Genotype", "block"), measure.vars = c("gr0", "gr2", "gr4", "gr6", "gr8", "gr24.5", "gr32"), variable.name = "time", value.name = "growthrate")
        koe[,3] <- as.numeric(gsub("gr", "", unlist(koe[,3])))

        #if(drop.0 == T) { koe <- filter(koe, time != 0) } #Bit inefficient to have this here

        #fit the model
        start.val <- c(b0 = 4.4, b1 = 2, th = 4)
        try(malli <- nls(growthrate ~ b0 - b1*2^(-time/th), start = start.val, trace = F, data = koe))

        #Extract needed coef
        res.mat[i,1] <- genotypes[i] #Store genotype label
        res.mat[i,2] <- summary(malli)[["coefficients"]][3,1] #time to half growthrate
        res.mat[i,3] <- summary(malli)[["coefficients"]][3,2] #SE of time to half growthrate

    } #End for loop

#Genotype set-2 needs to be fit separately
#koe <- filter(data, Genotype == "set-2")
#koe <- melt(koe, id.vars = c("Genotype", "block"), measure.vars = c("gr0", "gr2", "gr4", "gr6", "gr8", "gr24.5", "gr32"), variable.name = "time", value.name = "growthrate")
#        koe[,3] <- as.numeric(gsub("gr", "", unlist(koe[,3])))

#Need to drop two outlier observations
#koe[24,4] <- NA
#koe[35,4] <- NA
#New start values
#start.val <- c(b0 = 3.4, b1 = 1.9, th = 3.5)
#malli <- nls(growthrate ~ b0 - b1*2^(-time/th), start = start.val, trace = F, data = koe)
#res.mat[17,2] <- summary(malli)[["coefficients"]][3,1] #time to half growthrate
#res.mat[17,3] <- summary(malli)[["coefficients"]][3,2] #SE of time to half growthrate

lags.40to30 <- res.mat
colnames(lags.40to30) <- c("Genotype", "lag", "se")

#Testing differences between lagtimes
aineisto <- melt(data, id.vars = c("Genotype", "block"), measure.vars = c("gr0", "gr2", "gr4", "gr6", "gr8", "gr24.5", "gr32"), variable.name = "time", value.name = "growthrate")
aineisto[,3] <- as.numeric(gsub("gr", "", unlist(aineisto[,3])))

#Changing the order of genotypes, to have control (2489) as the first
aineisto$Genotype <- factor(aineisto$Genotype, levels = c("cont2489", "dim-2", "dmm-2", "set-1", "set-2", "set-7", "hda-1", "hda-4", "nst-1", "nst-2", "nst-4", "dcl-1 dcl-2", "qde-1", "qde-2", "qip", "aof2", "elp3", "lid2"), labels = c("Control", "dim-2", "dmm-2", "set-1", "set-2", "set-7", "hda-1", "hda-4", "nst-1", "nst-2", "nst-4", "dcl-1 dcl-2", "qde-1", "qde-2", "qip", "aof2", "elp3", "lid2" ))

aineisto <- filter(aineisto, is.na(growthrate) == F) #Remove missing observations
start.val <- list(fixed = c(4, rep(0,17), 2, rep(0,17), 2, rep(0,17))) 

mut.lag.40to30.test <- gnls(growthrate ~ form(time, b0, b1, th), params = list(b0 ~ Genotype, b1 ~ Genotype, th ~ Genotype), start = start.val, data = aineisto)
summary(mut.lag.40to30.test)

####  Then lag times for 30 to 40 shift  ######
data <- lag30to40
#Remove the first three replicates (54 lines)
#data <- data[-c(1:54),]

data[,1] <- factor(data[,1]) #Make sure that levels are OK

    genotypes <- levels(data[,1]) #genotypes
    res.mat <- matrix(rep(0, length(genotypes)*3), ncol = 3) #Results matrix, genotype, lag, se
    res.mat <- data.frame(res.mat)

for(i in 1:length(genotypes)) {
        koe <- filter(data, Genotype == genotypes[i])
        koe <- melt(koe, id.vars = c("Genotype", "block"), measure.vars = c("gr2", "gr4", "gr6", "gr8", "gr24.5", "gr32"), variable.name = "time", value.name = "growthrate")
        koe[,3] <- as.numeric(gsub("gr", "", unlist(koe[,3])))

        koe <- filter(koe, time != 0)  #Remove time point 0, because it is from 30 C

        #fit the model
        start.val <- c(b0 = 3, b1 = 6.1, th = 0.58)
        try(malli <- nls(growthrate ~ b0 - b1*2^(-time/th), start = start.val, trace = F, data = koe))

        #Extract needed coef
        res.mat[i,1] <- genotypes[i] #Store genotype label
        res.mat[i,2] <- summary(malli)[["coefficients"]][3,1] #time to half growthrate
        res.mat[i,3] <- summary(malli)[["coefficients"]][3,2] #SE of time to half growthrate

    } #End for loop


#Manual adjustment

#Dmm-2
koe <- filter(data, Genotype == "dmm-2")
koe <- melt(koe, id.vars = c("Genotype", "block"), measure.vars = c("gr2", "gr4", "gr6", "gr8", "gr24.5", "gr32"), variable.name = "time", value.name = "growthrate")
koe[,3] <- as.numeric(gsub("gr", "", unlist(koe[,3])))
koe[8,4] <- NA #Remove outlier

start.val <- c(b0 = 2.3, b1 = 6.1, th = 0.625)
malli <- nls(growthrate ~ b0 - b1*2^(-time/th), start = start.val, trace = F, data = koe)
res.mat[5,2] <- summary(malli)[["coefficients"]][3,1] #time to half growthrate
res.mat[5,3] <- summary(malli)[["coefficients"]][3,2]

#hda-1
koe <- filter(data, Genotype == "hda-1")
koe <- melt(koe, id.vars = c("Genotype", "block"), measure.vars = c("gr2", "gr4", "gr6", "gr8", "gr24.5", "gr32"), variable.name = "time", value.name = "growthrate")
koe[,3] <- as.numeric(gsub("gr", "", unlist(koe[,3])))
koe[4,4] <- NA #Remove outlier

start.val <- c(b0 = 2.3, b1 = 6.1, th = 0.625)
malli <- nls(growthrate ~ b0 - b1*2^(-time/th), start = start.val, trace = F, data = koe)
res.mat[7,2] <- summary(malli)[["coefficients"]][3,1] #time to half growthrate
res.mat[7,3] <- summary(malli)[["coefficients"]][3,2]

#qde-2
koe <- filter(data, Genotype == "qde-2")
koe <- melt(koe, id.vars = c("Genotype", "block"), measure.vars = c("gr2", "gr4", "gr6", "gr8", "gr24.5", "gr32"), variable.name = "time", value.name = "growthrate")
koe[,3] <- as.numeric(gsub("gr", "", unlist(koe[,3])))

start.val <- c(b0 = 2.6, b1 = 5.11, th = 0.5625) #Needed better starting values
malli <- nls(growthrate ~ b0 - b1*2^(-time/th), start = start.val, trace = T, data = koe)
res.mat[14,2] <- summary(malli)[["coefficients"]][3,1] #time to half growthrate
res.mat[14,3] <- summary(malli)[["coefficients"]][3,2]

#set-1
koe <- filter(data, Genotype == "set-1")
koe <- melt(koe, id.vars = c("Genotype", "block"), measure.vars = c("gr2", "gr4", "gr6", "gr8", "gr24.5", "gr32"), variable.name = "time", value.name = "growthrate")
koe[,3] <- as.numeric(gsub("gr", "", unlist(koe[,3])))

#Growthrate goes down during all the time, (slow drop from 30?)
res.mat[16,2] <- NA #time to half growthrate
res.mat[16,3] <- NA

lags.30to40 <- res.mat
colnames(lags.30to40) <- c("Genotype", "lag", "se")

#Testing differences between lagtimes
aineisto2 <- melt(data, id.vars = c("Genotype", "block"), measure.vars = c("gr2", "gr4", "gr6", "gr8", "gr24.5", "gr32"), variable.name = "time", value.name = "growthrate")
aineisto2[,3] <- as.numeric(gsub("gr", "", unlist(aineisto2[,3])))
aineisto2 <- filter(aineisto2, time != 0)  #Remove time point 0, because it is from 30 C
aineisto2 <- filter(aineisto2, Genotype != "set-1") #The function used cannot be fit to set-1
aineisto2$Genotype <- factor(aineisto2$Genotype) #Setting the factor to be correct

#Changing the order of genotypes, to have control (2489) as the first
aineisto2$Genotype <- factor(aineisto2$Genotype, levels = c("cont2489", "dim-2", "dmm-2", "set-2", "set-7", "hda-1", "hda-4", "nst-1", "nst-2", "nst-4", "dcl-1 dcl-2", "qde-1", "qde-2", "qip", "aof2", "elp3", "lid2"), labels = c("Control", "dim-2", "dmm-2", "set-2", "set-7", "hda-1", "hda-4", "nst-1", "nst-2", "nst-4", "dcl-1 dcl-2", "qde-1", "qde-2", "qip", "aof2", "elp3", "lid2" ))

aineisto2[c(57, 122),4] <- NA
aineisto2 <- filter(aineisto2, is.na(growthrate) == F) #Remove missing observations

#Some convergence problems with the model from 30 to 40
#This is due to genotype "dmm-2" where growth rate goes down at time points 24 and 32
aineisto2 <- filter(aineisto2, !(Genotype == "dmm-2" & time > 8)) #Removing these observations

#aineisto2 <- filter(aineisto2, Genotype != "hda-1")
#aineisto2 <- filter(aineisto2, Genotype != "dmm-2")
#aineisto2 <- filter(aineisto2, Genotype != "qde-2")
#aineisto2$Genotype <- factor(aineisto2$Genotype)
#start.val <- list(b0 = rep(2.88,14), b1 = rep(1.75,14), th = rep(1.26,14))
ngenot <- length(levels(aineisto2$Genotype))
start.val <- list(b0 = rep(2.88,ngenot), b1 = rep(1.75,ngenot), th = rep(1.26,ngenot))

#mut.model.30to40 <- nls(growthrate ~ b0[Genotype] - b1[Genotype]*2^(-time/th[Genotype]), start = start.val, trace = T, data = aineisto2)

mut.lag.30to40.test <- gnls(growthrate ~ form(time, b0, b1, th), params = list(b0 ~ Genotype, b1 ~ Genotype, th ~ Genotype), start = start.val, data = aineisto2)
summary(mut.lag.30to40.test)


#Manual plotting
#plot(c(1,35), c(1.5,4.5), type = "n")
#points(koe$time, koe$growthrate)
#lines(seq(0,35,length.out = 100), my.predict.gr(coef(malli), seq(0,35,length.out = 100)))

#my.predict.gr <- function(coefs, time) {
#    coefs[1] - coefs[2] * 2^(-time/coefs[3])
#}

#Making a combined dataset for plotting
colnames(lags.30to40) <- c("Genotype", "30to40.lag", "30to40.se")
colnames(lags.40to30) <- c("Genotype", "40to30.lag", "40to30.se")
lags.all <- cbind(lags.30to40, lags.40to30[,-1])
lagtemp <- melt(lags.all, id.vars = "Genotype", measure.vars = c("30to40.lag", "40to30.lag"), variable.name = "temp.shift", value.name = "lag")
lagtemp.2 <- melt(lags.all, id.vars = "Genotype", measure.vars = c("30to40.se", "40to30.se"), variable.name = "temp.shift", value.name = "se")[,3]
lags.all <- cbind(lagtemp, lagtemp.2)
lags.all[,2] <- factor(lags.all[,2], labels = c("shift30to40", "shift40to30"))
colnames(lags.all)[4] <- "se"
#variable lags.all contains all lag measurements and se

#Changing the order of genotypes
lags.all$Genotype <- factor(lags.all$Genotype, levels = c("cont2489", "dim-2", "dmm-2", "set-1", "set-2", "set-7", "hda-1", "hda-4", "nst-1", "nst-2", "nst-4", "dcl-1 dcl-2", "qde-1", "qde-2", "qip", "aof2", "elp3", "lid2"), labels = c("Control", "dim-2", "dmm-2", "set-1", "set-2", "set-7", "hda-1", "hda-4", "nst-1", "nst-2", "nst-4", "dcl-1 dcl-2", "qde-1", "qde-2", "qip", "aof2", "elp3", "lid2" ))


### *** Plotting the data

#All genotypes from 30 to 40
ggplot(lagmutants30to40.summary, aes(x = time, y = gr.mean, group = Genotype, colour = Genotype)) +
    geom_point() +
    geom_line(size = 1) +
    geom_errorbar(aes(ymin = gr.mean - gr.se, ymax = gr.mean + gr.se), width = 0.05) +
    expand_limits(x = -1) +    
    scale_y_continuous( breaks = seq(1,4.5,0.5)) +
    scale_x_continuous(breaks = seq(0,32,2)) +
    geom_vline(aes(xintercept = 0), linetype = "dashed") +
    labs(y = "Growth rate (mm / h)", x = "Time since temperature switch (h)") +
    background_grid(major = "xy", minor = "none")

#Need to split the data by genotypes, so that graphs are more clear


#All genotypes from 40 to 30
ggplot(lagmutants40to30.summary, aes(x = time, y = gr.mean, group = Genotype, colour = Genotype)) +
    geom_point() +
    geom_line(size = 1) +
    geom_errorbar(aes(ymin = gr.mean - gr.se, ymax = gr.mean + gr.se), width = 0.05) +
    expand_limits(x = -1) +    
    scale_y_continuous( breaks = seq(1,4.5,0.5)) +
    scale_x_continuous(breaks = seq(0,32,2)) +
    geom_vline(aes(xintercept = 0), linetype = "dashed") +
    labs(y = "Growth rate (mm / h)", x = "Time since temperature switch (h)") +
    background_grid(major = "xy", minor = "none")


#Plot mutants by functional groups
#Methylation mutants
meth.40to30 <- filter(lagmutants40to30.summary, Genotype == "cont2489" | Genotype == "dim-2" | Genotype == "dmm-2")

p.meth.40to30 <- ggplot(meth.40to30, aes(x = time, y = gr.mean, group = Genotype, colour = Genotype)) +
    geom_point() +
    geom_line(size = 1) +
    geom_errorbar(aes(ymin = gr.mean - gr.se, ymax = gr.mean + gr.se), width = 0.05) +
    expand_limits(x = -1) +
    scale_x_continuous(breaks = seq(0,32,2)) +
    scale_y_continuous(limits =c(0.8, 5), breaks=seq(1, 5, .5), expand = c(0,0)) +   
    geom_vline(aes(xintercept = 0), linetype = "dashed") +
    annotate("text", x = c(-1.5,1.5), y = c(4.4,4.4), label = c("40 °C", "30 °C")) +     
    labs(y = "Growth rate (mm / h)", x = "Time since temperature switch (h)") +
    scale_colour_manual(values = cbbPalette, labels = c("Control", "dim-2 (DNA methylation)", "dmm-2")) +
    theme(legend.position = c(.5, .25), legend.background = element_rect(fill="transparent")) +    
    background_grid(major = "xy", minor = "none")

#Histone methylation mutants
hist.40to30 <- filter(lagmutants40to30.summary, Genotype == "cont2489" | Genotype == "set-1" | Genotype == "set-2" | Genotype == "set-7")

p.hist.40to30 <- ggplot(hist.40to30, aes(x = time, y = gr.mean, group = Genotype, colour = Genotype)) +
    geom_point() +
    geom_line(size = 1) +
    geom_errorbar(aes(ymin = gr.mean - gr.se, ymax = gr.mean + gr.se), width = 0.05) +
    expand_limits(x = -1) +
    scale_x_continuous(breaks = seq(0,32,2)) +
    scale_y_continuous(limits =c(0.8, 5), breaks=seq(1, 5, .5), expand = c(0,0)) +      
    geom_vline(aes(xintercept = 0), linetype = "dashed") +
    annotate("text", x = c(-1.5,1.5), y = c(4.4,4.4), label = c("40 °C", "30 °C")) +
    labs(y = "Growth rate (mm / h)", x = "Time since temperature switch (h)") +
    scale_colour_manual(values = cbbPalette, labels = c("Control", "set-1 (H3K4me3)", "set-2 (H3K36me)", "set-7 (H3K27me3)")) +
    theme(legend.position = c(.5, .25), legend.background = element_rect(fill="transparent")) +    
    background_grid(major = "xy", minor = "none")

#Histone deacetylation mutants
histdeacet.40to30 <- filter(lagmutants40to30.summary, Genotype == "cont2489" | Genotype == "hda-1" | Genotype == "hda-4")

p.deacet.40to30 <- ggplot(histdeacet.40to30, aes(x = time, y = gr.mean, group = Genotype, colour = Genotype)) +
    geom_point() +
    geom_line(size = 1) +
    geom_errorbar(aes(ymin = gr.mean - gr.se, ymax = gr.mean + gr.se), width = 0.05) +
    expand_limits(x = -1) +
    scale_x_continuous(breaks = seq(0,32,2)) +
    scale_y_continuous(limits =c(0.8, 5), breaks=seq(1, 5, .5), expand = c(0,0)) +    
    geom_vline(aes(xintercept = 0), linetype = "dashed") +
    annotate("text", x = c(-1.5,1.5), y = c(4.4,4.4), label = c("40 °C", "30 °C")) +
    labs(y = "Growth rate (mm / h)", x = "Time since temperature switch (h)") +
    scale_colour_manual(values = cbbPalette, labels = c("Control", "hda-1", "hda-4")) +
    theme(legend.position = c(.5, .25), legend.background = element_rect(fill="transparent")) +    
    background_grid(major = "xy", minor = "none")

#Histone deacetylation class III mutants
deacetIII.40to30 <- filter(lagmutants40to30.summary, Genotype == "cont2489" | Genotype == "nst-1" | Genotype == "nst-2" | Genotype == "nst-4")

p.deacetIII.40to30 <- ggplot(deacetIII.40to30, aes(x = time, y = gr.mean, group = Genotype, colour = Genotype)) +
    geom_point() +
    geom_line(size = 1) +
    geom_errorbar(aes(ymin = gr.mean - gr.se, ymax = gr.mean + gr.se), width = 0.05) +
    expand_limits(x = -1) +
    scale_x_continuous(breaks = seq(0,32,2)) +
    scale_y_continuous(limits =c(0.8, 5), breaks=seq(1, 5, .5), expand = c(0,0)) +    
    geom_vline(aes(xintercept = 0), linetype = "dashed") +
    annotate("text", x = c(-1.5,1.5), y = c(4.4,4.4), label = c("40 °C", "30 °C")) +
    labs(y = "Growth rate (mm / h)", x = "Time since temperature switch (h)") +
    scale_colour_manual(values = cbbPalette, labels = c("Control", "nst-1", "nst-2", "nst-4")) +
    theme(legend.position = c(.5, .25), legend.background = element_rect(fill="transparent")) +    
    background_grid(major = "xy", minor = "none")

#RNA interference mutants
rna.40to30 <- filter(lagmutants40to30.summary, Genotype == "cont2489" | Genotype == "dcl-1 dcl-2" | Genotype == "qde-1" | Genotype == "qde-2" | Genotype == "qip")

p.rna.40to30 <- ggplot(rna.40to30, aes(x = time, y = gr.mean, group = Genotype, colour = Genotype)) +
    geom_point() +
    geom_line(size = 1) +
    geom_errorbar(aes(ymin = gr.mean - gr.se, ymax = gr.mean + gr.se), width = 0.05) +
    expand_limits(x = -1) +
    scale_x_continuous(breaks = seq(0,32,2)) +
    scale_y_continuous(limits =c(0.8, 5), breaks=seq(1, 5, .5), expand = c(0,0)) +    
    geom_vline(aes(xintercept = 0), linetype = "dashed") +
    annotate("text", x = c(-1.5,1.5), y = c(4.4,4.4), label = c("40 °C", "30 °C")) +
    labs(y = "Growth rate (mm / h)", x = "Time since temperature switch (h)") +
    scale_colour_manual(values = cbbPalette, labels = c("Control", "dcl-1 dcl-2 (Dicer)", "qde-1 (RNA pol)", "qde-2 (Argonaute)", "qip (Exonuclease)")) +
    theme(legend.position = c(.5, .25), legend.background = element_rect(fill="transparent")) +    
    background_grid(major = "xy", minor = "none")

#Other mutants
other.40to30 <- filter(lagmutants40to30.summary, Genotype == "cont2489" | Genotype == "aof2" | Genotype == "elp3" | Genotype == "lid2")
cbbPalette2 <- c(cbbPalette[2],cbbPalette[1],cbbPalette[3:8])

p.other.40to30 <- ggplot(other.40to30, aes(x = time, y = gr.mean, group = Genotype, colour = Genotype)) +
    geom_point() +
    geom_line(size = 1) +
    geom_errorbar(aes(ymin = gr.mean - gr.se, ymax = gr.mean + gr.se), width = 0.05) +
    expand_limits(x = -1) +
    scale_x_continuous(breaks = seq(0,32,2)) +
    scale_y_continuous(limits =c(0.8, 5), breaks=seq(1, 5, .5), expand = c(0,0)) +    
    geom_vline(aes(xintercept = 0), linetype = "dashed") +
    annotate("text", x = c(-1.5,1.5), y = c(4.4,4.4), label = c("40 °C", "30 °C")) +
    labs(y = "Growth rate (mm / h)", x = "Time since temperature switch (h)") +
    scale_colour_manual(values = cbbPalette2, breaks = c("cont2489", "aof2", "elp3", "lid2"), labels = c("Control", "aof2", "elp3", "lid2")) +
    theme(legend.position = c(.5, .25), legend.background = element_rect(fill="transparent")) +    
    background_grid(major = "xy", minor = "none")    


#Make a combined plot of all genotypes
#It is a bit difficult to fit everything into one plot that looks OK in the PDF. May need do trials.
mutant.panel.lag.40to30.plot <- plot_grid(p.meth.40to30, p.hist.40to30, p.deacet.40to30, p.deacetIII.40to30, p.rna.40to30, p.other.40to30, labels = c("A", "B", "C", "D", "E", "F"), ncol = 2)
save_plot("lag40to30_mutant_lags.pdf", mutant.panel.lag.40to30.plot, ncol = 2, nrow = 3, base_height = 5, base_width = 8 )

####################################
### Plotting lag from 30 to 40 #####
###################################


#Methylation mutants
meth.30to40 <- filter(lagmutants30to40.summary, Genotype == "cont2489" | Genotype == "dim-2" | Genotype == "dmm-2")

p.meth.30to40 <- ggplot(meth.30to40, aes(x = time, y = gr.mean, group = Genotype, colour = Genotype)) +
    geom_point() +
    geom_line(size = 1) +
    geom_errorbar(aes(ymin = gr.mean - gr.se, ymax = gr.mean + gr.se), width = 0.05) +
    expand_limits(x = -1) +
    scale_x_continuous(breaks = seq(0,32,2)) +
    scale_y_continuous(limits =c(0.8, 4.5), breaks=seq(1, 4.5, .5), expand = c(0,0)) +   
    geom_vline(aes(xintercept = 0), linetype = "dashed") +
    annotate("text", x = c(-1.5,1.5), y = c(4.4,4.4), label = c("30 °C", "40 °C")) +     
    labs(y = "Growth rate (mm / h)", x = "Time since temperature switch (h)") +
    scale_colour_manual(values = cbbPalette, labels = c("Control", "dim-2 (DNA methylation)", "dmm-2")) +
    theme(legend.position = c(.5, .25), legend.background = element_rect(fill="transparent")) +    
    background_grid(major = "xy", minor = "none")

#Histone methylation mutants
hist.30to40 <- filter(lagmutants30to40.summary, Genotype == "cont2489" | Genotype == "set-1" | Genotype == "set-2" | Genotype == "set-7")

p.hist.30to40 <- ggplot(hist.30to40, aes(x = time, y = gr.mean, group = Genotype, colour = Genotype)) +
    geom_point() +
    geom_line(size = 1) +
    geom_errorbar(aes(ymin = gr.mean - gr.se, ymax = gr.mean + gr.se), width = 0.05) +
    expand_limits(x = -1) +
    scale_x_continuous(breaks = seq(0,32,2)) +
    scale_y_continuous(limits =c(0.8, 4.5), breaks=seq(1, 4.5, .5), expand = c(0,0)) +      
    geom_vline(aes(xintercept = 0), linetype = "dashed") +
    annotate("text", x = c(-1.5,1.5), y = c(4.4,4.4), label = c("30 °C", "40 °C")) +
    labs(y = "Growth rate (mm / h)", x = "Time since temperature switch (h)") +
    scale_colour_manual(values = cbbPalette, labels = c("Control", "set-1 (H3K4me3)", "set-2 (H3K36me)", "set-7 (H3K27me3)")) +
    theme(legend.position = c(.5, .85), legend.background = element_rect(fill="transparent")) +    
    background_grid(major = "xy", minor = "none")

#Histone deacetylation mutants
histdeacet.30to40 <- filter(lagmutants30to40.summary, Genotype == "cont2489" | Genotype == "hda-1" | Genotype == "hda-4")

p.deacet.30to40 <- ggplot(histdeacet.30to40, aes(x = time, y = gr.mean, group = Genotype, colour = Genotype)) +
    geom_point() +
    geom_line(size = 1) +
    geom_errorbar(aes(ymin = gr.mean - gr.se, ymax = gr.mean + gr.se), width = 0.05) +
    expand_limits(x = -1) +
    scale_x_continuous(breaks = seq(0,32,2)) +
    scale_y_continuous(limits =c(0.8, 4.5), breaks=seq(1, 4.5, .5), expand = c(0,0)) +    
    geom_vline(aes(xintercept = 0), linetype = "dashed") +
    annotate("text", x = c(-1.5,1.5), y = c(4.4,4.4), label = c("30 °C", "40 °C")) +
    labs(y = "Growth rate (mm / h)", x = "Time since temperature switch (h)") +
    scale_colour_manual(values = cbbPalette, labels = c("Control", "hda-1", "hda-4")) +
    theme(legend.position = c(.5, .85), legend.background = element_rect(fill="transparent")) +    
    background_grid(major = "xy", minor = "none")

#Histone deacetylation class III mutants
deacetIII.30to40 <- filter(lagmutants30to40.summary, Genotype == "cont2489" | Genotype == "nst-1" | Genotype == "nst-2" | Genotype == "nst-4")

p.deacetIII.30to40 <- ggplot(deacetIII.30to40, aes(x = time, y = gr.mean, group = Genotype, colour = Genotype)) +
    geom_point() +
    geom_line(size = 1) +
    geom_errorbar(aes(ymin = gr.mean - gr.se, ymax = gr.mean + gr.se), width = 0.05) +
    expand_limits(x = -1) +
    scale_x_continuous(breaks = seq(0,32,2)) +
    scale_y_continuous(limits =c(0.8, 4.5), breaks=seq(1, 4.5, .5), expand = c(0,0)) +    
    geom_vline(aes(xintercept = 0), linetype = "dashed") +
    annotate("text", x = c(-1.5,1.5), y = c(4.4,4.4), label = c("30 °C", "40 °C")) +
    labs(y = "Growth rate (mm / h)", x = "Time since temperature switch (h)") +
    scale_colour_manual(values = cbbPalette, labels = c("Control", "nst-1", "nst-2", "nst-4")) +
    theme(legend.position = c(.5, .25), legend.background = element_rect(fill="transparent")) +    
    background_grid(major = "xy", minor = "none")

#RNA interference mutants
rna.30to40 <- filter(lagmutants30to40.summary, Genotype == "cont2489" | Genotype == "dcl-1 dcl-2" | Genotype == "qde-1" | Genotype == "qde-2" | Genotype == "qip")

p.rna.30to40 <- ggplot(rna.30to40, aes(x = time, y = gr.mean, group = Genotype, colour = Genotype)) +
    geom_point() +
    geom_line(size = 1) +
    geom_errorbar(aes(ymin = gr.mean - gr.se, ymax = gr.mean + gr.se), width = 0.05) +
    expand_limits(x = -1) +
    scale_x_continuous(breaks = seq(0,32,2)) +
    scale_y_continuous(limits =c(0.8, 4.5), breaks=seq(1, 4.5, .5), expand = c(0,0)) +    
    geom_vline(aes(xintercept = 0), linetype = "dashed") +
    annotate("text", x = c(-1.5,1.5), y = c(4.4,4.4), label = c("30 °C", "40 °C")) +
    labs(y = "Growth rate (mm / h)", x = "Time since temperature switch (h)") +
    scale_colour_manual(values = cbbPalette, labels = c("Control", "dcl-1 dcl-2 (Dicer)", "qde-1 (RNA pol)", "qde-2 (Argonaute)", "qip (Exonuclease)")) +
    theme(legend.position = c(.5, .25), legend.background = element_rect(fill="transparent")) +    
    background_grid(major = "xy", minor = "none")

#Other mutants
other.30to40 <- filter(lagmutants30to40.summary, Genotype == "cont2489" | Genotype == "aof2" | Genotype == "elp3" | Genotype == "lid2")
cbbPalette2 <- c(cbbPalette[2],cbbPalette[1],cbbPalette[3:8])

p.other.30to40 <- ggplot(other.30to40, aes(x = time, y = gr.mean, group = Genotype, colour = Genotype)) +
    geom_point() +
    geom_line(size = 1) +
    geom_errorbar(aes(ymin = gr.mean - gr.se, ymax = gr.mean + gr.se), width = 0.05) +
    expand_limits(x = -1) +
    scale_x_continuous(breaks = seq(0,32,2)) +
    scale_y_continuous(limits =c(0.8, 4.5), breaks=seq(1, 4.5, .5), expand = c(0,0)) +    
    geom_vline(aes(xintercept = 0), linetype = "dashed") +
    annotate("text", x = c(-1.5,1.5), y = c(4.4,4.4), label = c("30 °C", "40 °C")) +
    labs(y = "Growth rate (mm / h)", x = "Time since temperature switch (h)") +
    scale_colour_manual(values = cbbPalette2, breaks = c("cont2489", "aof2", "elp3", "lid2"), labels = c("Control", "aof2", "elp3", "lid2")) +
    theme(legend.position = c(.5, .25), legend.background = element_rect(fill="transparent")) +    
    background_grid(major = "xy", minor = "none")

#Make a combined plot of all genotypes
#It is a bit difficult to fit everything into one plot that looks OK in the PDF. May need do trials.
mutant.panel.lag.30to40.plot <- plot_grid(p.meth.30to40, p.hist.30to40, p.deacet.30to40, p.deacetIII.30to40, p.rna.30to40, p.other.30to40, labels = c("A", "B", "C", "D", "E", "F"), ncol = 2)
save_plot("lag30to40_mutant_lags.pdf", mutant.panel.lag.30to40.plot, ncol = 2, nrow = 3, base_height = 5, base_width = 8 )


#Old ref
meth.geno <- all.geno.complete[all.geno.complete$Genotype == "cont2489" | all.geno.complete$Genotype == "dim-2" | all.geno.complete$Genotype == "dmm-2",]

plot.meth <- ggplot(meth.geno, aes(x = Freq, y = growthrate, group = Genotype, colour = Genotype)) +
    geom_point() +
    geom_line(size = 1) +
    geom_errorbar(limits, width = 0.05) +
    labs(y = "Growth rate (mm / h)", x = "Step duration (min)") +
    ylim(1, 3.5) +
    scale_x_continuous(breaks = c(30, 60, 90, 120, 150, 240, 480, 720)) +
    scale_colour_manual(values = cbbPalette, labels = c("Control", "dim-2 (DNA methylation)", "dmm-2")) +
    theme(legend.position = c(.5, .25), legend.background = element_rect(fill="transparent")) +
    background_grid(major = "xy", minor = "none")


#Old graph (for reference)
plot.40to30 <- ggplot(summary.40to30, aes(x = time, y = growthrate, group = genotype, colour = genotype)) +
    geom_point() +
    geom_line(size = 1) +
    geom_errorbar(limits, width = 0.05) +
    expand_limits(x = -1) +
    geom_vline(aes(xintercept = 0), linetype = "dashed") +
    annotate("text", x = c(-1.5,1.5), y = c(4.4,4.4), label = c("40 C", "30 C")) +   
    labs(y = "Growth rate (mm / h)", x = "Time since temperature switch (h)") +
    background_grid(major = "xy", minor = "none") +
    scale_colour_manual(values = c("black", "darkgrey"),  labels = c("2489", "qde-2")) +
    scale_x_continuous(breaks=seq(0, 32, 2)) +
    scale_y_continuous(limits =c(1.5, 4.6), breaks=seq(1.5, 4.5, .5)) +
    theme(legend.position = c(0.8,0.2))  

#Plotting the lag times
#data is lags.all
hlines <- data.frame(temp.shift = levels(lags.all$temp.shift), yval = c(lags.all[2,3],lags.all[20,3]))
mylabels <- c(shift30to40 = "Shift from 30 to 40 °C", shift40to30 = "Shift from 40 to 30 °C")
pdf("lagtimes.pdf")
ggplot(lags.all, aes(x = Genotype, y = lag)) +
    geom_point() +
    geom_errorbar(aes(ymin = lag - se, max = lag + se), width = 0.1) +
    coord_flip() +
    geom_hline(aes(yintercept = yval), linetype = "dashed",  data = hlines) +
    ylab(expression(paste("lag"[50], " (h)"))) +    
    facet_wrap(~ temp.shift, labeller = labeller(temp.shift = mylabels))
dev.off()



### * Using observed lagtimes to model growth
source("growth_model.R")

all.geno <- summarySE(data = aineisto, measurevar = "gr.chamber", groupvars = c("Freq", "Genotype"), na.rm = TRUE)
colnames(all.geno)[4] <- "growthrate"
control <- all.geno[all.geno$Genotype == "cont2489",]

all.geno.long <- summarySE(data = aineisto.long, measurevar = "gr.long.adj", groupvars = c("Freq", "Genotype"), na.rm = TRUE)
colnames(all.geno.long)[4] <- "growthrate"
control.long <- all.geno.long[all.geno.long$Genotype == "cont2489",]

control <- rbind(control, control.long)
control$Freq <- factor(c(15, 30, 60, 90, 120, 150, 240, 480, 720))
control[,1] <- factor(control[,1])


#Lag function parameters from fitted functions
lagpara <- matrix(c(coef(fm.40to30),coef(fm.30to40)), byrow = TRUE, ncol = 3)
freq <- c(30, 60, 90, 120, 150, 240, 480, 720)/60

model.lag.growth(freq, lagpara = lagpara)

model.results <- matrix(rep(0,8*2), ncol = 2)
model.results[,1] <- c(0.5, 1, 1.5, 2, 2.5, 4.0, 8.0, 12.0)
for(i in 1:8) { model.results[i,2] <- model.lag.growth(freq = model.results[i,1], lagpara = lagpara) }

#Naive lag function model cannot account for the growth in fluctuating temps
#What is the growth rate during the first hour after switch?
distances <- lagdata.40to30[,-c(1,2,16,17)]
hour1.40to30 <- (distances[4] - distances[3]) / (tindex.45[4] - tindex.45[3])
hour1.40to30 <- cbind(hour1.40to30, lagdata.40to30[,1]) #Mean is 2.65

distances <- lagdata.30to40[,-c(1,2,16,17)]
hour1.30to40 <- (distances[4] - distances[3]) / (tindex.45[4] - tindex.45[3])
hour1.30to40 <- cbind(hour1.30to40, lagdata.30to40[,1]) #Mean is 1.6

#Modifying the 30 to 40 lag function

#New model where the parameters are updated to reflect partial acclimation


model.results2 <- matrix(rep(0,8*2), ncol = 2)
model.results2[,1] <- c(0.5, 1, 1.5, 2, 2.5, 4.0, 8.0, 12.0)
for(i in 1:8) { model.results2[i,2] <- model.lag.growth.refined(freq = model.results2[i,1], lagpara = lagpara) }

#Plotting the results
#Comparing the predicted data to observations, dropping 15 min freq.
pdf("lagpredictions.pdf", width = 10)
cols <- c("Observed" = "black", "Predicted - initial lag model" = "#3591d1", "Predicted - refined lag model" = "#62c76b")
ggplot(control, aes(x = as.numeric(as.character(Freq)), y = growthrate, group = 1)) +
    geom_point(aes(fill = "Observed")) +
    geom_line(size = 1) +
    geom_errorbar(limits, width = 0.05) +
    geom_hline(aes(yintercept = temp40.2489[3]), colour = "red") +
    geom_hline(aes(yintercept = temp40.2489[3]-temp40.2489[5]), linetype = 2, colour = "red") +
    geom_hline(aes(yintercept = temp40.2489[3]+temp40.2489[5]), linetype = 2, colour = "red") +
    geom_hline(aes(yintercept = (const.control[1,3]+const.control[3,3])/2), linetype = 2, colour = "grey50") +
    geom_line(aes(x = c(30, 60, 90, 120, 150, 240, 480, 720), y = model.results[,2]), size = 0.5, col = "#3591d1"  ) +      
    geom_point(aes(x = c(30, 60, 90, 120, 150, 240, 480, 720), y = model.results[,2], fill = "Predicted - initial lag model"), shape = 21 ) +
    geom_line(aes(x = c(30, 60, 90, 120, 150, 240, 480, 720), y = model.results2[,2]), size = 0.5, col = "#62c76b" ) +  
    geom_point(aes(x = c(30, 60, 90, 120, 150, 240, 480, 720), y = model.results2[,2], fill = "Predicted - refined lag model"), shape = 21) +    
    ylim(1.5, 4) +
    scale_colour_manual(name = "Data", values = cols) +
    scale_fill_manual(name = "Data", values = cols) +
    scale_x_continuous(breaks = c(30, 60, 90, 120, 150, 240, 480, 720)) +
    theme(legend.position = c(.25,.9)) +
    labs(y = "Growth rate (mm / h)", x = "Step duration (min)") + 
    annotate("text", x = 160.5, y = 3.63, size = 4.3, label = "Predicted - no lag") +
    annotate("segment", x = 89.92, xend = 99.07, y = 3.63, yend = 3.63, size = 1, colour = "grey50") +
    annotate("text", x = 149, y = 3.54, size = 4.3, label = "Constant 40 C") +
    annotate("segment", x = 89.92, xend = 99.07, y = 3.54, yend = 3.54, size = 1, colour = "red") +
    background_grid(major = "xy", minor = "none")
dev.off()

#Calculating MSD values for the different models
#control[,4] #Observed data
#model.results[,2] #Initial lag model data
#model.results2[,2] #Refined lag model data
#temp40.2489[3] #Growth rate at constant 40

msd.initial <- mean((control[,4] - model.results[,2])^2)
msd.refined <- mean((control[,4] - model.results2[,2])^2)
msd.constant <-  mean((control[,4] - as.numeric(temp40.2489[3]))^2)
msd.nolag <- mean((control[,4] - (const.control[1,3]+const.control[3,3])/2)^2)



#Get all data
obs1 <- aineisto[aineisto$Genotype == "cont2489", c(2,3,22)]
obs2 <- aineisto.long[(aineisto.long$Genotype == "cont2489"), c(2,3,22)]
colnames(obs1)[3] <- "gr"
colnames(obs2)[3] <- "gr"
observed <- c(obs1[order(obs1$Freq),3], obs2[order(obs2$Freq),3])
model1 <- sort(rep(model.results[,2],5))
model2 <- sort(rep(model.results2[,2],5))
model3 <- rep(as.numeric(temp40.2489[3]), 40)
model4 <- rep(((const.control[1,3]+const.control[3,3])/2),40)


### * Supplementary plots

#Making a supplementary figure that shows heating and cooling in growth chamber

library(cowplot)

gcdelta <- read.csv("gc_change.csv", header = TRUE)

heatdata <- gcdelta[gcdelta$Type == "heating",]
coolingdata <- gcdelta[gcdelta$Type == "cooling",]

#Making a plot
cols <- c("Air temperature" = "blue", "Tube temperature" = "red")
my.ylab <- expression(paste("Temperature (", degree,"C)"))
heat.plot <- ggplot(heatdata, aes(x = Time, y = Temp.Air)) +
    geom_point(data = heatdata, aes(x = Time, y = Temp.Air, colour = "Air temperature")) +
    geom_line(data = heatdata, aes(x = Time, y = Temp.Air, colour = "Air temperature")) +
    geom_point(data = heatdata, aes(x = Time, y = Temp.tube, colour = "Tube temperature")) +
    geom_line(data = heatdata, aes(x = Time, y = Temp.tube, colour = "Tube temperature")) +
    labs(y = my.ylab, x = "Time (min)") +
    scale_x_continuous(breaks = seq(0, 60, 10)) +
    scale_colour_manual(name = "Data", values = cols) +
    scale_fill_manual(name = "Data", values = cols) +
    theme(legend.position = c(.8,.2))

cool.plot <- ggplot(coolingdata, aes(x = Time, y = Temp.Air)) +
    geom_point(data = coolingdata, aes(x = Time, y = Temp.Air, colour = "Air temperature")) +
    geom_line(data = coolingdata, aes(x = Time, y = Temp.Air, colour = "Air temperature")) +
    geom_point(data = coolingdata, aes(x = Time, y = Temp.tube, colour = "Tube temperature")) +
    geom_line(data = coolingdata, aes(x = Time, y = Temp.tube, colour = "Tube temperature")) +
    labs(y = my.ylab, x = "Time (min)") +
    scale_x_continuous(breaks = seq(0, 60, 10)) +
    scale_colour_manual(name = "Data", values = cols) +
    scale_fill_manual(name = "Data", values = cols) +
    theme(legend.position = c(.75,.4))

heatcool.plot <- plot_grid(heat.plot, cool.plot, labels = c("A", "B"))
save_plot("heatcool.pdf", heatcool.plot, base_width = 8)

