#This file contains scripts for modeling growth in fluctuating environment

   
#This growth model uses the empirical lag functions to model growth in fluctuating environments
#freq = is the time cultures spend in each temperature (in hours)
#lagpara = matrix of lagfunction parameters, 1st row = lag from 40 to 30, b0, b1, b2; 2nd row = lag from 30 to 40 b0, b1, b2
#This is a naive version of the model as it changes to a different lag function even if the growth has not gotten 
model.lag.growth <- function(freq, lagpara) {
    
    #Lag1 from 40 to 30 C
    lagf <- function(x, b0, b1, b2) {b0 - b1*2^(-x/b2)}

    #b0 = 4.453, b1 = 2.028, b2 = 2.064 for lagfunction from 40 to 30 for example
    tulos1 <- integrate(lagf, lower = 0, upper = freq, b0 = lagpara[1,1], b1 = lagpara[1,2], b2 = lagpara[1,3])
    tulos2 <- integrate(lagf, lower = 0, upper = freq, b0 = lagpara[2,1], b1 = lagpara[2,2], b2 = lagpara[2,3])

    #tulos1 + tulos2 gives growth over on fluctuation
    #Standardizing that for one hour
    growth.rate <- (as.numeric(tulos1[1]) + as.numeric(tulos2[1])) / (2*freq)

    return(growth.rate)
}
    

#This growth model updates the lag parameter (B_1) based on the growth rate that was reached in the previous temperature
model.lag.growth.refined <- function(freq, lagpara) {

    #Lag function
    lagf <- function(x, b0, b1, b2) {b0 - b1*2^(-x/b2)}

    #Initial lag parameters
    inits <- lagpara
    #Distance grown over all cycles
    distance <- 0
    #Number of cycles to use, empirical measurements were initially done over ~ 103 hours, the number of full cycles that fit to this time
    ncycles <- floor(103/2*freq)

    for(i in 1:ncycles) {

        #First from 40 to 30
        tulos1 <- integrate(lagf, lower = 0, upper = freq, b0 = lagpara[1,1], b1 = lagpara[1,2], b2 = lagpara[1,3]) #Distance grown
        current.gr <- lagf(freq, b0 = lagpara[1,1], b1 = lagpara[1,2], b2 = lagpara[1,3]) #Current growth rate

        if(current.gr < lagpara[2,1]) { lagpara[2,2] <- lagpara[2,1] - current.gr } else { lagpara[2,2] <- inits[2,2] }

        #Then from 30 to 40
        tulos2 <- integrate(lagf, lower = 0, upper = freq, b0 = lagpara[2,1], b1 = lagpara[2,2], b2 = lagpara[2,3]) #Distance grown
        current.gr <-  #Current growth rate

        if(current.gr < lagpara[1,1]) { lagpara[1,2] <- lagpara[1,1] - current.gr } else { lagpara[1,2] <- inits[1,2] }
        
        #Updating distance grown
        distance <- distance + as.numeric(tulos1[1]) + as.numeric(tulos2[1])
    }

    total.time <- 2*freq*ncycles #Total time used in simulation

    growth.rate <- distance / total.time #Calculate growth rate
    return(growth.rate)
}
